==> keygen-0.0.2.tar.gz: keygen-0.0.2/README.md <==
[![PyPI version](https://badge.fury.io/py/keygen.svg)](https://badge.fury.io/py/keygen)

keygen v0.0.2
======================================

Простой кейген для генерации всевозможных ключей, токенов и т.п.

Установка
--------------------------------------
```bash
> pip install keygen
```

Параметры коммандной строки
--------------------------------------
```bash
> keygen [-s SYMBOLS] [-l LENGTH] [-v]
    -s, --symbols     # Набор символов для генерации:
                         u - ASCII uppercase letters
                         l - ASCII lowercase letters
                         d - digits
                         p - punctuation symbols
                         h - HEX digits
                         o - OCT digits
                         b - BIN digits
                         По умолчанию: uldp
    -l, --length      # Длинна генерируемого ключа
                         По умолчанию: 32
    -v, --verbose     # Вывод дополнительной информации
```

Использование
--------------------------------------
```bash
# Генерация 32-символьного ключа
> keygen

# Генерация 64-символьного ключа с использованием HEX символов
> keygen -s h -l 64

# Генерация 128-символьного ключа с использованием всех доступных символов
> keygen -s uldp -l 128

# Генерация ключа с выводом дополнительной информации
> keygen -v
```

Список изменений
--------------------------------------
* **v0.0.2** \[_22.03.2018_\]

    - Добавлена проверка входных параметров.
    
* **v0.0.1** \[_20.03.2018_\]

    - Начало работы над проектом.

==> keygen-0.0.3.tar.gz: keygen-0.0.3/README.md <==
[![PyPI version](https://badge.fury.io/py/keygen.svg)](https://badge.fury.io/py/keygen)

keygen v0.0.3
======================================

Простой кейген для генерации всевозможных ключей, токенов и т.п.

Установка
--------------------------------------
```bash
> pip install keygen
```

Параметры коммандной строки
--------------------------------------
```bash
> keygen [-s SYMBOLS] [-l LENGTH] [-v]
    -s, --symbols     # Набор символов для генерации:
                         u - ASCII uppercase letters
                         l - ASCII lowercase letters
                         d - digits
                         p - punctuation symbols
                         h - HEX digits
                         o - OCT digits
                         b - BIN digits
                         По умолчанию: uldp
    -l, --length      # Длинна генерируемого ключа
                         По умолчанию: 32
    -e, --emulate     # Эмуляция работы алгоритма шифрования
                         Поддерживаются алгоритмы:
                           md5, sha1, sha224, sha256, sha384, sha512, uuid
                         По умолчанию: None
```

Использование
--------------------------------------
```bash
# Генерация 32-символьного ключа
> keygen

# Генерация 64-символьного ключа с использованием HEX символов
> keygen -s h -l 64

# Генерация 128-символьного ключа с использованием всех доступных символов
> keygen -s uldp -l 128

# Генерация ключа, выглядящего как UUID 
> keygen -e uuid
```

Список изменений
--------------------------------------
* **v0.0.3** \[_27.05.2020_\]

    - Алгоритм рандома изменен на системный.
    - Добавлена возможность генерации ключей, выглядящих как результат работы некоторых криптографических функций.
    - Убран редим вывода дополнительной информации.
    
* **v0.0.2** \[_22.03.2018_\]

    - Добавлена проверка входных параметров.
    
* **v0.0.1** \[_20.03.2018_\]

    - Начало работы над проектом.
